==> ant-design-vue-4.0.4.jar: META-INF/resources/webjars/ant-design-vue/4.0.4/lib/steps/style/index.d.ts <==
import type { FullToken } from '../../theme/internal';
export interface ComponentToken {
    descriptionWidth: number;
}
export interface StepsToken extends FullToken<'Steps'> {
    processTailColor: string;
    stepsNavArrowColor: string;
    stepsIconSize: number;
    stepsIconCustomSize: number;
    stepsIconCustomTop: number;
    stepsIconCustomFontSize: number;
    stepsIconTop: number;
    stepsIconFontSize: number;
    stepsTitleLineHeight: number;
    stepsSmallIconSize: number;
    stepsDotSize: number;
    stepsCurrentDotSize: number;
    stepsNavContentMaxWidth: string;
    processIconColor: string;
    processTitleColor: string;
    processDescriptionColor: string;
    processIconBgColor: string;
    processIconBorderColor: string;
    processDotColor: string;
    waitIconColor: string;
    waitTitleColor: string;
    waitDescriptionColor: string;
    waitTailColor: string;
    waitIconBgColor: string;
    waitIconBorderColor: string;
    waitDotColor: string;
    finishIconColor: string;
    finishTitleColor: string;
    finishDescriptionColor: string;
    finishTailColor: string;
    finishIconBgColor: string;
    finishIconBorderColor: string;
    finishDotColor: string;
    errorIconColor: string;
    errorTitleColor: string;
    errorDescriptionColor: string;
    errorTailColor: string;
    errorIconBgColor: string;
    errorIconBorderColor: string;
    errorDotColor: string;
    stepsNavActiveColor: string;
    stepsProgressSize: number;
    inlineDotSize: number;
    inlineTitleColor: string;
    inlineTailColor: string;
}
declare const _default: (_prefixCls?: import("vue").Ref<string>) => import("../../theme/internal").UseComponentStyleResult;
export default _default;

==> ant-design-vue-4.2.6.jar: META-INF/resources/webjars/ant-design-vue/4.2.6/lib/steps/style/index.d.ts <==
import type { FullToken } from '../../theme/internal';
export interface ComponentToken {
    descriptionWidth: number;
}
export interface StepsToken extends FullToken<'Steps'> {
    processTailColor: string;
    stepsNavArrowColor: string;
    stepsIconSize: number;
    stepsIconCustomSize: number;
    stepsIconCustomTop: number;
    stepsIconCustomFontSize: number;
    stepsIconTop: number;
    stepsIconFontSize: number;
    stepsTitleLineHeight: number;
    stepsSmallIconSize: number;
    stepsDotSize: number;
    stepsCurrentDotSize: number;
    stepsNavContentMaxWidth: string;
    processIconColor: string;
    processTitleColor: string;
    processDescriptionColor: string;
    processIconBgColor: string;
    processIconBorderColor: string;
    processDotColor: string;
    waitIconColor: string;
    waitTitleColor: string;
    waitDescriptionColor: string;
    waitTailColor: string;
    waitIconBgColor: string;
    waitIconBorderColor: string;
    waitDotColor: string;
    finishIconColor: string;
    finishTitleColor: string;
    finishDescriptionColor: string;
    finishTailColor: string;
    finishIconBgColor: string;
    finishIconBorderColor: string;
    finishDotColor: string;
    errorIconColor: string;
    errorTitleColor: string;
    errorDescriptionColor: string;
    errorTailColor: string;
    errorIconBgColor: string;
    errorIconBorderColor: string;
    errorDotColor: string;
    stepsNavActiveColor: string;
    stepsProgressSize: number;
    inlineDotSize: number;
    inlineTitleColor: string;
    inlineTailColor: string;
}
declare const _default: (_prefixCls?: import("vue").Ref<string, string>) => import("../../theme/internal").UseComponentStyleResult;
export default _default;
